@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.69 2005/06/20 14:52:15 vnoel Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.70 2005/09/23 14:34:39 vnoel Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -236,7 +236,7 @@ static set_font (GtkFontButton *widget, gpointer data)
 {
 	GDictPrefDialog *pref_dialog = data;
 	GDictWindow *gdict = pref_dialog->gdict;
-	gchar *fontname;
+	const gchar *fontname;
 
 	fontname = gtk_font_button_get_font_name (widget);
 	gdict_defbox_set_font (gdict->defbox, fontname);
@@ -542,13 +542,9 @@ gdict_pref_dialog_new (GDictWindow *gdict)
   pref_dialog = GDICT_PREF_DIALOG (g_object_new (GDICT_TYPE_PREF_DIALOG, NULL));
   pref_dialog->gdict = gdict;
   pref_dialog->context = context;
-	if (gdict->defbox->fontname) {
-		gchar *fullname;
-		fullname = g_strdup_printf ("%s %d", gdict->defbox->fontname, gdict->defbox->fontsize);
+	if (gdict->defbox->fontname)
 		gtk_font_button_set_font_name (GTK_FONT_BUTTON(pref_dialog->font_button),
-																	 fullname);
-		g_free (fullname);
-	}
+																	 gdict->defbox->fontname);
   gdict_pref_dialog_set (pref_dialog);
 
   pref_dialog_reset_db (pref_dialog);
